@@ -17,9 +17,10 @@ put through a deprecation cycle and retracted. After the retraction,
 postfix dereferences will always be recognized. This is the default
 behaviour now.
 
-Starting with the first release after October 1 2020, the first use of
-this argument will warn. Six months after that all uses will warn. After
-a further six months, all uses will become fatal.
+Starting with version 0.074_01, the first use of this argument warned.
+warn. With version 0.079_01, all uses will warn. With version 0.080_01,
+all uses will become fatal. With the first release on or after April 15
+2022 all mention of this argument will be removed.
 
 =head1 INHERITANCE
 
@@ -66,14 +67,6 @@ for little tangible gain.
 
 =head1 NOTICE
 
-The use of this class to parse non-regexp quote-like strings was an
-experiment that I consider failed. Therefore this use is B<deprecated>
-in favor of L<PPIx::QuoteLike|PPIx::QuoteLike>. As of version 0.058_01,
-the first use of the C<parse> argument to L<new()|/new> resulted in a
-warning. As of version 0.062_01, all uses of the C<parse> argument
-resulted in a warning. As of version 0.068_01, the C<parse> argument
-will become fatal.
-
 The author will attempt to preserve the documented interface, but if the
 interface needs to change to correct some egregiously bad design or
 implementation decision, then it will change.  Any incompatible changes
@@ -102,7 +95,7 @@ Known examples of this include:
 
 =item C<$(> no longer interpolates as of Perl 5.005, per C<perl5005delta>.
 
-Newer Perls seem to parse this as C<qr{$}> (i.e. and end-of-string or
+Newer Perls seem to parse this as C<qr{$}> (i.e. an end-of-string or
 newline assertion) followed by an open parenthesis, and that is what
 C<PPIx::Regexp> does.
 
@@ -153,6 +146,17 @@ were introduced to deal with this complication.
 is parsed as the octal equivalent of C<\x{...}>. This is its meaning as
 of perl 5.13.2. Before 5.13.2 it was simply literal C<'o'> and so on.
 
+=item C<x{,3}>
+
+(with first count omitted) is allowed as a quantifier as of Perl 5.33.6.
+The previous parse made this all literals.
+
+=item C<x{ 0 , 3 }>
+
+(with spaces inside but adjacent to curly brackets, or around the comma
+if any) is allowed as a quantifier as of Perl 5.33.6. The previous parse
+made this all literals.
+
 =back
 
 There are very probably other examples of this. When they come to light
@@ -194,7 +198,7 @@ use PPIx::Regexp::Util qw{
 use Scalar::Util qw{ refaddr };
 use Text::Tabs ();
 
-our $VERSION = '0.073';
+our $VERSION = '0.082';
 
 =head2 new
 
@@ -272,18 +276,6 @@ specified as a L<PPI::Element|PPI::Element>.
 If no location can be determined, the various C<location()> methods will
 return C<undef>.
 
-=item parse parse_type
-
-This option specifies what kind of parse is to be done. Possible values
-are C<'regex'>, C<'string'>, or C<'guess'>. Any value but C<'regex'> is
-experimental.
-
-As it turns out, I consider parsing non-regexp quote-like things with
-this class to be a failed experiment, and the relevant functionality is
-being deprecated and removed in favor of
-L<PPIx::QuoteLike|PPIx::QuoteLike>. See above for details. As of version
-0.068_01, any use of this option throws an exception.
-
 =item postderef Boolean
 
 B<THIS ARGUMENT IS DEPRECATED>.
@@ -293,8 +285,9 @@ This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
 experimental feature was introduced in Perl 5.19.5.
 
-The default is the value of
-C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is true. When
+As of version 0.074_01, the default is true.  Through release 0.074, the
+default was the value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which was true. When
 originally introduced this was false, but was documented as becoming
 true when and if postfix dereferencing became mainstream. The  intent to
 mainstream was announced with Perl 5.23.1, and became official (so to
@@ -473,7 +466,6 @@ any objects specified are removed from the cache.
 
 sub can_be_quantified { return; }
 
-
 =head2 capture_names
 
  foreach my $name ( $re->capture_names() ) {
@@ -587,7 +579,6 @@ sub extract_regexps {
     );
 }
 
-
 =head2 failures
 
  print "There were ", $re->failures(), " parse failures\n";
@@ -937,10 +928,20 @@ L<Regexp::Parser|Regexp::Parser>, which parses a bare regular expression
 navigation model. After a long hiatus, this module has been adopted, and
 is again supported.
 
+L<YAPE::Regex|YAPE::Regex>, which provides the parse tree, and has a
+mechanism to subclass the various element classes for customization. The
+most-recent release is 2011, but the CPAN testers results are still all
+green. Companion module L<YAPE::Regex::Explain|YAPE::Regex::Explain>
+says what the various pieces of a regex do, though constructs added in
+perl 5.10 and later are not supported. I have no idea how I missed this
+when I originally went looking for C<Regexp> parsers.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -948,7 +949,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
